@@ -6,7 +6,12 @@ package Mite::Attribute;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003000';
+our $VERSION   = '0.003001';
+
+has _order =>
+  is            => 'rw',
+  init_arg      => undef,
+  builder       => sub { state $order = 0; $order++ };
 
 has class =>
   is            => rw,
@@ -171,11 +176,19 @@ sub BUILD {
 sub clone {
     my ( $self, %args ) = ( shift, @_ );
 
+    if ( exists $args{is} ) {
+        require Carp;
+        Carp::croak( "Cannot use the `is` shortcut when extending an attribute" );
+    }
+
     my %inherit = %$self;
 
-    # Lazy attributes should be rebuilt by clone
+    # type will need to be rebuilt
     delete $inherit{type} if $args{isa} || $args{type};
+
+    # these should not be cloned at all
     delete $inherit{coderef_default_variable};
+    delete $inherit{_order};
 
     return ref($self)->new( %inherit, %args );
 }
@@ -415,6 +428,8 @@ sub compile_init {
         ) . ';';
     }
 
+    $code = "$code;" if $code !~ /;$/;
+
     return $code;
 }
 
