@@ -13,7 +13,7 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Initialize attributes
-    if ( exists $args->{"file"} ) { my $value = do { my $to_coerce = $args->{"file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "file", "Path"); $self->{"file"} = $value;  }
+    if ( exists $args->{"file"} ) { my $value = do { my $to_coerce = $args->{"file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "file", "Path"); $self->{"file"} = $value;  };
     if ( exists $args->{"source"} ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{"source"}) and $args->{"source"}->isa(q[Mite::Source]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "source", "InstanceOf[\"Mite::Source\"]"); $self->{"source"} = $args->{"source"};  } else { require Carp; Carp::croak("Missing key in constructor: source") } require Scalar::Util && Scalar::Util::weaken($self->{"source"});
 
     # Enforce strict constructor
