@@ -13,11 +13,11 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Initialize attributes
-    if ( exists $args->{"config_file"} ) { my $value = do { my $to_coerce = $args->{"config_file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "config_file", "Path"); $self->{"config_file"} = $value;  }
-    if ( exists $args->{"data"} ) { do { package Mite::Miteception; ref($args->{"data"}) eq 'HASH' } or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "data", "HashRef"); $self->{"data"} = $args->{"data"};  }
-    if ( exists $args->{"mite_dir"} ) { my $value = do { my $to_coerce = $args->{"mite_dir"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "mite_dir", "Path"); $self->{"mite_dir"} = $value;  }
-    if ( exists $args->{"mite_dir_name"} ) { do { package Mite::Miteception; defined($args->{"mite_dir_name"}) and do { ref(\$args->{"mite_dir_name"}) eq 'SCALAR' or ref(\(my $val = $args->{"mite_dir_name"})) eq 'SCALAR' } } or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "mite_dir_name", "Str"); $self->{"mite_dir_name"} = $args->{"mite_dir_name"};  } else { my $value = do { my $default_value = ".mite"; do { package Mite::Miteception; defined($default_value) and do { ref(\$default_value) eq 'SCALAR' or ref(\(my $val = $default_value)) eq 'SCALAR' } } or do { require Carp; Carp::croak(sprintf "Type check failed in default: %s should be %s", "mite_dir_name", "Str") }; $default_value }; $self->{"mite_dir_name"} = $value;  }
-    if ( exists $args->{"search_for_mite_dir"} ) { do { package Mite::Miteception; !ref $args->{"search_for_mite_dir"} and (!defined $args->{"search_for_mite_dir"} or $args->{"search_for_mite_dir"} eq q() or $args->{"search_for_mite_dir"} eq '0' or $args->{"search_for_mite_dir"} eq '1') } or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "search_for_mite_dir", "Bool"); $self->{"search_for_mite_dir"} = $args->{"search_for_mite_dir"};  } else { my $value = do { my $default_value = "1"; (!ref $default_value and (!defined $default_value or $default_value eq q() or $default_value eq '0' or $default_value eq '1')) or do { require Carp; Carp::croak(sprintf "Type check failed in default: %s should be %s", "search_for_mite_dir", "Bool") }; $default_value }; $self->{"search_for_mite_dir"} = $value;  }
+    if ( exists $args->{"mite_dir_name"} ) { do { package Mite::Miteception; defined($args->{"mite_dir_name"}) and do { ref(\$args->{"mite_dir_name"}) eq 'SCALAR' or ref(\(my $val = $args->{"mite_dir_name"})) eq 'SCALAR' } } or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "mite_dir_name", "Str"); $self->{"mite_dir_name"} = $args->{"mite_dir_name"};  } else { my $value = do { my $default_value = ".mite"; do { package Mite::Miteception; defined($default_value) and do { ref(\$default_value) eq 'SCALAR' or ref(\(my $val = $default_value)) eq 'SCALAR' } } or do { require Carp; Carp::croak(sprintf "Type check failed in default: %s should be %s", "mite_dir_name", "Str") }; $default_value }; $self->{"mite_dir_name"} = $value;  };
+    if ( exists $args->{"mite_dir"} ) { my $value = do { my $to_coerce = $args->{"mite_dir"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "mite_dir", "Path"); $self->{"mite_dir"} = $value;  };
+    if ( exists $args->{"config_file"} ) { my $value = do { my $to_coerce = $args->{"config_file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "config_file", "Path"); $self->{"config_file"} = $value;  };
+    if ( exists $args->{"data"} ) { do { package Mite::Miteception; ref($args->{"data"}) eq 'HASH' } or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "data", "HashRef"); $self->{"data"} = $args->{"data"};  };
+    if ( exists $args->{"search_for_mite_dir"} ) { do { package Mite::Miteception; !ref $args->{"search_for_mite_dir"} and (!defined $args->{"search_for_mite_dir"} or $args->{"search_for_mite_dir"} eq q() or $args->{"search_for_mite_dir"} eq '0' or $args->{"search_for_mite_dir"} eq '1') } or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "search_for_mite_dir", "Bool"); $self->{"search_for_mite_dir"} = $args->{"search_for_mite_dir"};  } else { my $value = do { my $default_value = "1"; (!ref $default_value and (!defined $default_value or $default_value eq q() or $default_value eq '0' or $default_value eq '1')) or do { require Carp; Carp::croak(sprintf "Type check failed in default: %s should be %s", "search_for_mite_dir", "Bool") }; $default_value }; $self->{"search_for_mite_dir"} = $value;  };
 
     # Enforce strict constructor
     my @unknown = grep not( /\A(?:config_file|data|mite_dir(?:_name)?|search_for_mite_dir)\z/ ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
